[Libreoffice-commits] core.git: fpicker/source framework/source include/framework include/osl include/ucbhelper include/unotools jurt/com libreofficekit/qa qadevOOo/tests sfx2/source svx/source vcl/unx wizards/com

Andrea Gelmini andrea.gelmini at gelma.net
Sun Jan 14 15:32:01 UTC 2018


 fpicker/source/win32/filepicker/FilterContainer.hxx          |    2 +-
 framework/source/dispatch/loaddispatcher.cxx                 |    4 ++--
 framework/source/inc/loadenv/loadenv.hxx                     |   10 +++++-----
 framework/source/jobs/job.cxx                                |   10 +++++-----
 framework/source/services/substitutepathvars.cxx             |    2 +-
 framework/source/uielement/addonstoolbarmanager.cxx          |    2 +-
 include/framework/framelistanalyzer.hxx                      |    2 +-
 include/osl/pipe_decl.hxx                                    |    2 +-
 include/ucbhelper/interceptedinteraction.hxx                 |    2 +-
 include/unotools/mediadescriptor.hxx                         |    2 +-
 jurt/com/sun/star/comp/loader/FactoryHelper.java             |    4 ++--
 libreofficekit/qa/unit/tiledrendering.cxx                    |    2 +-
 qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryAnalyzer.java |    4 ++--
 sfx2/source/doc/printhelper.cxx                              |    4 ++--
 svx/source/inc/docrecovery.hxx                               |    2 +-
 vcl/unx/generic/app/i18n_ic.cxx                              |    2 +-
 wizards/com/sun/star/wizards/document/OfficeDocument.java    |    2 +-
 wizards/com/sun/star/wizards/document/OfficeDocument.py      |    2 +-
 18 files changed, 30 insertions(+), 30 deletions(-)

New commits:
commit a452643b431803b613919871abf1a81de6de3464
Author: Andrea Gelmini <andrea.gelmini at gelma.net>
Date:   Sun Jan 14 12:42:46 2018 +0100

    Fix typos
    
    Change-Id: I2b4988e1d81fe60f7699362480cd739d2620c053
    Reviewed-on: https://gerrit.libreoffice.org/47856
    Tested-by: Jenkins <ci at libreoffice.org>
    Reviewed-by: Julien Nabet <serval2412 at yahoo.fr>

diff --git a/fpicker/source/win32/filepicker/FilterContainer.hxx b/fpicker/source/win32/filepicker/FilterContainer.hxx
index ffbe327f6463..89c3987aca45 100644
--- a/fpicker/source/win32/filepicker/FilterContainer.hxx
+++ b/fpicker/source/win32/filepicker/FilterContainer.hxx
@@ -26,7 +26,7 @@
 #include <vector>
 
 
-// helper class, only useable by OFilterContainer
+// helper class, only usable by OFilterContainer
 
 
 class CFilterContainer
diff --git a/framework/source/dispatch/loaddispatcher.cxx b/framework/source/dispatch/loaddispatcher.cxx
index 81141c347aae..5d1b7346fade 100644
--- a/framework/source/dispatch/loaddispatcher.cxx
+++ b/framework/source/dispatch/loaddispatcher.cxx
@@ -82,7 +82,7 @@ css::uno::Any LoadDispatcher::impl_dispatch( const css::util::URL& rURL,
     // may a dispatch request before is still in progress (?!).
     // Then we should wait a little bit and block this new request.
     // In case we run into the timeout, we should reject this new request
-    // and return "FAILED" as result. Otherwhise we can start this new operation.
+    // and return "FAILED" as result. Otherwise we can start this new operation.
     if (!m_aLoader.waitWhileLoading(2000)) // => 2 sec.
     {
         if (xListener.is())
@@ -98,7 +98,7 @@ css::uno::Any LoadDispatcher::impl_dispatch( const css::util::URL& rURL,
                 css::frame::DispatchResultEvent(xThis, css::frame::DispatchResultState::FAILURE, css::uno::Any()));
     }
 
-    // OK ... now the internal loader seems to be useable for new requests
+    // OK ... now the internal loader seems to be usable for new requests
     // and our owner frame seems to be valid for such operations.
     // Initialize it with all new but needed properties and start the loading.
     css::uno::Reference< css::lang::XComponent > xComponent;
diff --git a/framework/source/services/substitutepathvars.cxx b/framework/source/services/substitutepathvars.cxx
index b41660242210..6a074d471a29 100644
--- a/framework/source/services/substitutepathvars.cxx
+++ b/framework/source/services/substitutepathvars.cxx
@@ -247,7 +247,7 @@ OUString SubstitutePathVariables::GetWorkPath() const
     OUString aWorkPath;
     css::uno::Reference< css::container::XHierarchicalNameAccess > xPaths(officecfg::Office::Paths::Paths::get(m_xContext), css::uno::UNO_QUERY_THROW);
     if (!(xPaths->getByHierarchicalName("['Work']/WritePath") >>= aWorkPath))
-        // fallback in case config layer does not return an useable work dir value.
+        // fallback in case config layer does not return an usable work dir value.
         aWorkPath = GetWorkVariableValue();
 
     return aWorkPath;
diff --git a/framework/source/uielement/addonstoolbarmanager.cxx b/framework/source/uielement/addonstoolbarmanager.cxx
index 14ea5039035e..664e7798eb23 100644
--- a/framework/source/uielement/addonstoolbarmanager.cxx
+++ b/framework/source/uielement/addonstoolbarmanager.cxx
@@ -350,7 +350,7 @@ void AddonsToolBarManager::FillToolbar( const Sequence< Sequence< PropertyValue
                     }
                 }
 
-                // Notify controller implementation to its listeners. Controller is now useable from outside.
+                // Notify controller implementation to its listeners. Controller is now usable from outside.
                 Reference< XUpdatable > xUpdatable( xController, UNO_QUERY );
                 if ( xUpdatable.is() )
                 {
diff --git a/include/framework/framelistanalyzer.hxx b/include/framework/framelistanalyzer.hxx
index ce44de67207f..8112beccf49d 100644
--- a/include/framework/framelistanalyzer.hxx
+++ b/include/framework/framelistanalyzer.hxx
@@ -29,7 +29,7 @@
 /** These enums can be combined as flags to enable/disable
     special search algorithm during analyze phase.
     see impl_analyze() for further information.
-    But note: To be useable as flags, these enums
+    But note: To be usable as flags, these enums
     must be values of range [2^n]! */
 enum class FrameAnalyzerFlags
 {
diff --git a/include/osl/pipe_decl.hxx b/include/osl/pipe_decl.hxx
index 88247766a530..81bc4fd81183 100644
--- a/include/osl/pipe_decl.hxx
+++ b/include/osl/pipe_decl.hxx
@@ -37,7 +37,7 @@ protected:
 public:
 
     /** Does not create a pipe. Use assignment operator to
-        make this a useable pipe.
+        make this a usable pipe.
     */
     inline Pipe();
 
diff --git a/include/ucbhelper/interceptedinteraction.hxx b/include/ucbhelper/interceptedinteraction.hxx
index 8803c358c297..fc34fb1f4d15 100644
--- a/include/ucbhelper/interceptedinteraction.hxx
+++ b/include/ucbhelper/interceptedinteraction.hxx
@@ -176,7 +176,7 @@ class UCBHELPER_DLLPUBLIC InterceptedInteraction : public ::cppu::WeakImplHelper
                     const css::uno::Type&                                                                                             aType         );
 
 
-    // useable for derived classes
+    // usable for derived classes
     protected:
 
 
diff --git a/include/unotools/mediadescriptor.hxx b/include/unotools/mediadescriptor.hxx
index 9b0972b79050..24e8d4678ec0 100644
--- a/include/unotools/mediadescriptor.hxx
+++ b/include/unotools/mediadescriptor.hxx
@@ -42,7 +42,7 @@ namespace utl {
     @descr  It wraps a unordered_map around the Sequence< css::beans::PropertyValue >, which
             represent the MediaDescriptor item.
             Further this helper defines often used functions (as e.g. open of the required streams,
-            consistent checks etcpp.) and it defines all useable property names.
+            consistent checks etcpp.) and it defines all usable property names.
 
     @attention  This class isn't threadsafe and must be guarded from outside!
  */
diff --git a/libreofficekit/qa/unit/tiledrendering.cxx b/libreofficekit/qa/unit/tiledrendering.cxx
index 885bfda09bc4..db968eda2fba 100644
--- a/libreofficekit/qa/unit/tiledrendering.cxx
+++ b/libreofficekit/qa/unit/tiledrendering.cxx
@@ -48,7 +48,7 @@ OUString getFileURLFromSystemPath(OUString const & path)
 }
 
 // We specifically don't use the usual BootStrapFixture, as LOK does
-// all it's own setup and bootstrapping, and should be useable in a
+// all it's own setup and bootstrapping, and should be usable in a
 // raw C++ program.
 class TiledRenderingTest : public ::CppUnit::TestFixture
 {
diff --git a/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryAnalyzer.java b/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryAnalyzer.java
index d69523d5f973..6ddee8e5e62d 100644
--- a/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryAnalyzer.java
+++ b/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryAnalyzer.java
@@ -184,7 +184,7 @@ public class _XSingleSelectQueryAnalyzer extends MultiMethodTest {
 
     /**
     * Method <code>getGroupColumns</code> retunrs a <code>XIndexAccess</code>
-    * Test has ok status if returned value is an useable <code>XIndexAccess</code>
+    * Test has ok status if returned value is an usable <code>XIndexAccess</code>
     */
     public void _getGroupColumns() {
         try{
@@ -268,7 +268,7 @@ public class _XSingleSelectQueryAnalyzer extends MultiMethodTest {
 
     /**
     * Method <code>getGroupColumns</code> retunrs a <code>XIndexAccess</code>
-    * Test has ok status if returned value is an useable <code>XIndexAccess</code>
+    * Test has ok status if returned value is an usable <code>XIndexAccess</code>
     */
     public void _getOrderColumns() {
         try{
diff --git a/sfx2/source/doc/printhelper.cxx b/sfx2/source/doc/printhelper.cxx
index 296c53da0aa7..0005f2534870 100644
--- a/sfx2/source/doc/printhelper.cxx
+++ b/sfx2/source/doc/printhelper.cxx
@@ -519,7 +519,7 @@ class ImplUCBPrintWatcher : public ::osl::Thread
         }
 
         /* static helper to move the temp. file to the target location by using the ucb
-           It's static to be useable from outside too. So it's not really necessary to start
+           It's static to be usable from outside too. So it's not really necessary to start
            the thread, if finishing of the job was detected outside this thread.
            But it must be called without using a corresponding thread for the given parameter!
          */
@@ -634,7 +634,7 @@ void SAL_CALL SfxPrintHelper::print(const uno::Sequence< beans::PropertyValue >&
             {
                 // OK - it's not a valid URL. But may it's a simple
                 // system path directly. It will be supported for historical
-                // reasons. Otherwhise we break to much external code ...
+                // reasons. Otherwise we break to much external code ...
                 // We try to convert it to a file URL. If its possible
                 // we put the system path to the item set and let vcl work with it.
                 // No ucb or thread will be necessary then. In case it couldn't be
diff --git a/svx/source/inc/docrecovery.hxx b/svx/source/inc/docrecovery.hxx
index 5ec8fab16e9c..c74e20cce9db 100644
--- a/svx/source/inc/docrecovery.hxx
+++ b/svx/source/inc/docrecovery.hxx
@@ -86,7 +86,7 @@ enum class EDocStates
 
     /* FINAL STATES */
 
-    /// the Auto/Emergency saved document isn't useable any longer
+    /// the Auto/Emergency saved document isn't usable any longer
     Damaged           = 0x040,
     /// the Auto/Emergency saved document is not really up-to-date (some changes can be missing)
     Incomplete        = 0x080,
diff --git a/vcl/unx/generic/app/i18n_ic.cxx b/vcl/unx/generic/app/i18n_ic.cxx
index 8cf738c4ab62..64ad7fc190ff 100644
--- a/vcl/unx/generic/app/i18n_ic.cxx
+++ b/vcl/unx/generic/app/i18n_ic.cxx
@@ -558,7 +558,7 @@ SalI18N_InputContext::UpdateSpotLocation()
 }
 
 // set and unset the focus for the Input Context
-// the context may be NULL despite it is useable if the framewindow is
+// the context may be NULL despite it is usable if the framewindow is
 // in unmapped state
 
 void
diff --git a/wizards/com/sun/star/wizards/document/OfficeDocument.java b/wizards/com/sun/star/wizards/document/OfficeDocument.java
index 6a90726dd77c..1868c198915a 100644
--- a/wizards/com/sun/star/wizards/document/OfficeDocument.java
+++ b/wizards/com/sun/star/wizards/document/OfficeDocument.java
@@ -130,7 +130,7 @@ public class OfficeDocument
             xFrame = UnoRuntime.queryInterface(XFrame.class, xMSF.createInstance("com.sun.star.frame.Frame"));
             xFrame.initialize(xWindow);
 
-            //from now this frame is useable ...
+            //from now this frame is usable ...
             //and not part of the desktop tree.
             //You are alone with him .-)
 
diff --git a/wizards/com/sun/star/wizards/document/OfficeDocument.py b/wizards/com/sun/star/wizards/document/OfficeDocument.py
index 3886f1eb1c70..ba3b0976bd31 100644
--- a/wizards/com/sun/star/wizards/document/OfficeDocument.py
+++ b/wizards/com/sun/star/wizards/document/OfficeDocument.py
@@ -169,7 +169,7 @@ class OfficeDocument(object):
             traceback.print_exc()
 
         xFrame.initialize(xPeer)
-        #from now this frame is useable ...
+        #from now this frame is usable ...
         #and not part of the desktop tree.
         #You are alone with him .-)
         if listener is not None:


More information about the Libreoffice-commits mailing list
diff --git a/framework/source/inc/loadenv/loadenv.hxx b/framework/source/inc/loadenv/loadenv.hxx
index 87743974ae51..ca8999f889a9 100644
--- a/framework/source/inc/loadenv/loadenv.hxx
+++ b/framework/source/inc/loadenv/loadenv.hxx
@@ -369,7 +369,7 @@ public:
                 close the frame if it was created before in case loading failed.
 
         @throw  A LoadEnvException only in cases, where an internal error indicates,
-                that the complete load environment seems to be not useable in general.
+                that the complete load environment seems to be not usable in general.
                 In such cases a RuntimeException would be to hard for the outside code :-)
 
         @throw  A RuntimeException in case any internal process indicates, that
@@ -454,7 +454,7 @@ private:
                 and could be activated successfully. An empty reference otherwise.
 
         @throw  A LoadEnvException only in cases, where an internal error indicates,
-                that the complete load environment seems to be not useable in general.
+                that the complete load environment seems to be not usable in general.
                 In such cases a RuntimeException would be to hard for the outside code :-)
 
         @throw  A RuntimeException in case any internal process indicates, that
@@ -462,7 +462,7 @@ private:
      */
     css::uno::Reference< css::frame::XFrame > impl_searchAlreadyLoaded();
 
     /** @short  search for any target frame, which seems to be useable
                 for this load request.
 
         @descr  Because this special feature is bound to the target specifier "_default"
@@ -479,12 +479,12 @@ private:
                 </ul>
 
                 If a suitable target is located it will be locked. That's why the last rule
-                exists! If this method returns a valid frame reference, it was locked to be useable
+                exists! If this method returns a valid frame reference, it was locked to be usable
                 for this load request only. (Don't forget to reset this state later!)
                 Concurrent LoadEnv instances can synchronize her work be using such locks :-) HOPEFULLY
 
         @throw  A LoadEnvException only in cases, where an internal error indicates,
-                that the complete load environment seems to be not useable in general.
+                that the complete load environment seems to be not usable in general.
                 In such cases a RuntimeException would be to hard for the outside code :-)
 
         @throw  A RuntimeException in case any internal process indicates, that
@@ -462,7 +462,7 @@ private:
     css::uno::Reference< css::frame::XFrame > impl_searchAlreadyLoaded();
 
-    /** @short  search for any target frame, which seems to be useable
+    /** @short  search for any target frame, which seems to be usable
                 for this load request.
 
diff --git a/framework/source/jobs/job.cxx b/framework/source/jobs/job.cxx
index a0488bc45aae..e0df5442e5af 100644
--- a/framework/source/jobs/job.cxx
+++ b/framework/source/jobs/job.cxx
@@ -94,7 +94,7 @@ Job::Job( /*IN*/ const css::uno::Reference< css::uno::XComponentContext >& xCont
 /**
     @short  superfluous!
     @descr  Releasing of memory and reference must be done inside die() call.
-            Otherwhise it's a bug.
+            Otherwise it's a bug.
 */
 Job::~Job()
 {
@@ -175,7 +175,7 @@ void Job::execute( /*IN*/ const css::uno::Sequence< css::beans::NamedValue >& lD
     css::uno::Sequence< css::beans::NamedValue > lJobArgs = impl_generateJobArgs(lDynamicArgs);
 
     // It's necessary to hold us self alive!
     // Otherwhise we might die by ref count ...
     css::uno::Reference< css::task::XJobListener > xThis(static_cast< ::cppu::OWeakObject* >(this), css::uno::UNO_QUERY);
 
     try
@@ -274,7 +274,7 @@ void Job::execute( /*IN*/ const css::uno::Sequence< css::beans::NamedValue >& lD
     @descr  It doesn't matter if this request is called from inside or
             from outside. We release our internal structures and stop
             every activity. After doing so - this instance will not be
-            useable any longer! Of course we try to handle further requests
+            usable any longer! Of course we try to handle further requests
             carefully. Maybe someone else holds a reference to us ...
 */
 void Job::die()
@@ -663,7 +663,7 @@ void SAL_CALL Job::queryTermination( /*IN*/ const css::lang::EventObject& )
 {
     SolarMutexGuard g;
 
     // Otherwhise try to close() it
     css::uno::Reference< css::util::XCloseable > xClose(m_xJob, css::uno::UNO_QUERY);
     if (xClose.is())
     {
@@ -775,7 +775,7 @@ void SAL_CALL Job::queryClosing( const css::lang::EventObject& aEvent         ,
 
     // No veto ...
     // But don't call die() here or free our internal member.
     // This must be done inside notifyClosing() only. Otherwhise the
     // might stopped job has no chance to return its results or
     // call us back. We must give him the chance to finish it's work successfully.
 }
@@ -175,7 +175,7 @@ void Job::execute( /*IN*/ const css::uno::Sequence< css::beans::NamedValue >& lD
 
     // It's necessary to hold us self alive!
-    // Otherwhise we might die by ref count ...
+    // Otherwise we might die by ref count ...
     css::uno::Reference< css::task::XJobListener > xThis(static_cast< ::cppu::OWeakObject* >(this), css::uno::UNO_QUERY);
 
@@ -663,7 +663,7 @@ void SAL_CALL Job::queryTermination( /*IN*/ const css::lang::EventObject& )
     SolarMutexGuard g;
 
-    // Otherwhise try to close() it
+    // Otherwise try to close() it
     css::uno::Reference< css::util::XCloseable > xClose(m_xJob, css::uno::UNO_QUERY);
     if (xClose.is())
@@ -775,7 +775,7 @@ void SAL_CALL Job::queryClosing( const css::lang::EventObject& aEvent         ,
     // No veto ...
     // But don't call die() here or free our internal member.
-    // This must be done inside notifyClosing() only. Otherwhise the
+    // This must be done inside notifyClosing() only. Otherwise the
     // might stopped job has no chance to return its results or
     // call us back. We must give him the chance to finish it's work successfully.
diff --git a/jurt/com/sun/star/comp/loader/FactoryHelper.java b/jurt/com/sun/star/comp/loader/FactoryHelper.java
index dce8818384db..d6e28435d9b5 100644
--- a/jurt/com/sun/star/comp/loader/FactoryHelper.java
+++ b/jurt/com/sun/star/comp/loader/FactoryHelper.java
@@ -136,8 +136,8 @@ public class FactoryHelper {
                 }
             }
 
-            if(_constructor == null) // have not found a useable constructor
-                throw new com.sun.star.uno.RuntimeException(getClass().getName() + " can not find a useable constructor");
+            if(_constructor == null) // have not found a usable constructor
+                throw new com.sun.star.uno.RuntimeException(getClass().getName() + " can not find a usable constructor");
         }
 
         private final XMultiServiceFactory getSMgr( XComponentContext xContext )